wizzWifi
* This module is for educational purpose only
* developer is not responsible anything
* THIS MODULE IS SPECIFICALLY DONE FOR PEN TESTERS

usage 
```python
* importing main function
  from WizzHash import wizzWifi
*running scanner
  wizzWifi()
```
Developing WizzHash
* To install WizzHash, along with the tools you need to develop
   and run tests, run the following
  in your virtualenv.
```bash
$ pip install -e .[dev]
```
